Type

Type Alias Type 

pub type Type = c_uint;
Flags to indicate the intended use for the buffer - these are passed into gbm_bo_create(). The caller must set the union of all the flags that are appropriate

\sa Use gbm_device_is_format_supported() to check if the combination of format and use flags are supported